# pympls

A Python Parser for Blu-ray's MPLS Playlist files

`pip install pympls`

<p align="center">
<a href="https://python.org"><img src="https://img.shields.io/badge/python-3.6%2B-informational?style=flat-square" /></a>
<a href="https://github.com/rlaPHOENiX/pympls/blob/master/LICENSE"><img alt="GitHub license" src="https://img.shields.io/github/license/rlaPHOENiX/pympls?style=flat-square"></a>
<a href="https://www.codefactor.io/repository/github/rlaphoenix/pympls"><img src="https://www.codefactor.io/repository/github/rlaphoenix/pympls/badge" alt="CodeFactor" /></a>
<a href="https://www.codacy.com/manual/rlaPHOENiX/pympls?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=rlaPHOENiX/pympls&amp;utm_campaign=Badge_Grade"><img src="https://api.codacy.com/project/badge/Grade/d4f765fcf63249f78c156f2ecc980010"/></a>
<a href="https://github.com/rlaPHOENiX/pympls/issues"><img alt="GitHub issues" src="https://img.shields.io/github/issues/rlaPHOENiX/pympls?style=flat-square"></a>
<a href="http://makeapullrequest.com"><img src="https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square"></a>
</p>
